@@ -56,7 +56,7 @@ def service_mapping(uri, method):
             elif method == HTTP_METHOD_PUT:
                 return client.put(_uri, json_data=data)
             elif method == HTTP_METHOD_DELETE:
-                return client.delete(_uri)
+                return client.delete(_uri, json_data=data)
             else:
                 raise Exception('{}.{} is invalid method', f.__module__, f.__name__)
 
